==> haskell-hls-qualify-imported-names-plugin-2.1.0.0-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-qualify-imported-names-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-qualify-imported-names-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-qualify-imported-names-plugin-2.1.0.0-5P61RRvq9GwBPnaTbLefKk

key:
    hls-qualify-imported-names-plugin-2.1.0.0-5P61RRvq9GwBPnaTbLefKk

license:              Apache-2.0
maintainer:           shenjonathan0@gmail.com
author:               Jonathan Shen
synopsis:
    A Haskell Language Server plugin that qualifies imported names

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  02cdcd33a724ad373bb0162896378751
exposed:              True
exposed-modules:      Ide.Plugin.QualifyImportedNames
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-qualify-imported-names-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-qualify-imported-names-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-qualify-imported-names-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-qualify-imported-names-plugin
hs-libraries:
    HShls-qualify-imported-names-plugin-2.1.0.0-5P61RRvq9GwBPnaTbLefKk

depends:
    aeson-2.1.2.1-25X5lEqka86CxkXK2BMN9E base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 dlist-1.0-E99MqJW5mmB4kr4PCgIESI ghc-9.4.8
    ghcide-2.1.0.0-i5ImOMGmlU1PEzs0wu2yD
    hls-graph-2.1.0.0-KBySwUXVuDJ4GbLq0zEeAb
    hls-plugin-api-2.1.0.0-8R8xwTFYTzq2JDNNMyld8b
    lens-5.3.2-Gri7akg07hN4ZkbavAwqWU
    lsp-2.1.0.0-AJwFJfN2F9R6higrO7L8aE text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-DjNgsRwGYvfHy5WsKzKUzR

haddock-interfaces:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html/hls-qualify-imported-names-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-qualify-imported-names-plugin-2.1.0.0-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-qualify-imported-names-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-qualify-imported-names-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-qualify-imported-names-plugin-2.1.0.0-JUR30M6ex0vH4JTafacBFm

key:
    hls-qualify-imported-names-plugin-2.1.0.0-JUR30M6ex0vH4JTafacBFm

license:              Apache-2.0
maintainer:           shenjonathan0@gmail.com
author:               Jonathan Shen
synopsis:
    A Haskell Language Server plugin that qualifies imported names

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  67f0895d703a1a5aa0fe9ec140a957b0
exposed:              True
exposed-modules:      Ide.Plugin.QualifyImportedNames
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-qualify-imported-names-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-qualify-imported-names-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-qualify-imported-names-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-qualify-imported-names-plugin
hs-libraries:
    HShls-qualify-imported-names-plugin-2.1.0.0-JUR30M6ex0vH4JTafacBFm

depends:
    aeson-2.1.2.1-7cfkxE9Bq2x7khGuVuQDC7 base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 dlist-1.0-E99MqJW5mmB4kr4PCgIESI ghc-9.4.8
    ghcide-2.1.0.0-8iHR6PRdZCjHHO6RJzrNVV
    hls-graph-2.1.0.0-HomL2g1CAGvKuX5ZFVGgV9
    hls-plugin-api-2.1.0.0-LDWDIkrlg0GEI7zjdGOxF9
    lens-5.3.2-3x6i1OAeQ2c8gg8RvgTRSW
    lsp-2.1.0.0-KhWBdemCS618YV0Jldc3Cf text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-7E9U8fDCyyE7V5F5vC663n

haddock-interfaces:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html/hls-qualify-imported-names-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
